@@ -40,6 +40,9 @@ class Gist(github.GithubObject.CompletableGithubObject):
     This class represents Gists as returned for example by http://developer.github.com/v3/todo
     """
 
+    def __repr__(self):
+        return self.get__repr__({"id": self._id.value})
+
     @property
     def comments(self):
         """
