@@ -7,7 +7,8 @@
 # Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 #                                                                              #
-# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
+# This file is part of PyGithub.                                               #
+# http://pygithub.github.io/PyGithub/v1/index.html                             #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -34,6 +35,9 @@ class GitRef(github.GithubObject.CompletableGithubObject):
     This class represents GitRefs as returned for example by http://developer.github.com/v3/todo
     """
 
+    def __repr__(self):
+        return self.get__repr__({"ref": self._ref.value})
+
     @property
     def object(self):
         """
@@ -89,6 +93,22 @@ class GitRef(github.GithubObject.CompletableGithubObject):
         )
         self._useAttributes(data)
 
+    def get_statuses(self):
+        """
+        https://developer.github.com/v3/repos/statuses/#list-statuses-for-a-specific-ref
+        :calls: `GET /repos/:owner/:repo/commits/:ref/statuses`
+        :return:
+        """
+        pass
+
+    def get_status(self):
+        """
+        https://developer.github.com/v3/repos/statuses/#get-the-combined-status-for-a-specific-ref
+        :calls: `GET /repos/:owner/:repo/commits/:ref/status`
+        :return:
+        """
+        pass
+
     def _initAttributes(self):
         self._object = github.GithubObject.NotSet
         self._ref = github.GithubObject.NotSet
