@@ -36,6 +36,9 @@ class IssueComment(github.GithubObject.CompletableGithubObject):
     This class represents IssueComments as returned for example by http://developer.github.com/v3/todo
     """
 
+    def __repr__(self):
+        return self.get__repr__({"id": self._id.value, "user": self._user.value})
+
     @property
     def body(self):
         """
