@@ -57,6 +57,8 @@ from .OrganizationHasInMembers import *
 from .Organization import *
 from .PullRequest import *
 from .PullRequestComment import *
+from .PullRequestReview import *
+from .PullRequestReviewerRequests import *
 from .PullRequestFile import *
 from .RateLimiting import *
 from .Repository import *
