@@ -36,6 +36,9 @@ class Branch(Framework.TestCase):
         self.assertEqual(self.branch.name, "topic/RewriteWithGeneratedCode")
         self.assertEqual(self.branch.commit.sha, "1292bf0e22c796e91cc3d6e24b544aece8c21f2a")
 
+        # test __repr__() based on this attributes
+        self.assertEqual(self.branch.__repr__(), 'Branch(name="topic/RewriteWithGeneratedCode")')
+
     def testProtectedAttributes(self):
         self.branch = self.g.get_user().get_repo("PyGithub").get_protected_branch("master")
         self.assertEqual(self.branch.name, "master")
