@@ -48,3 +48,6 @@ class GitTree(Framework.TestCase):
         self.assertEqual(self.tree.tree[6].type, "tree")
         self.assertEqual(self.tree.tree[6].url, "https://api.github.com/repos/jacquev6/PyGithub/git/trees/60b4602b2c2070246c5df078fb7a5150b45815eb")
         self.assertEqual(self.tree.url, "https://api.github.com/repos/jacquev6/PyGithub/git/trees/f492784d8ca837779650d1fb406a1a3587a764ad")
+
+        # test __repr__() based on this attributes
+        self.assertEqual(self.tree.__repr__(), 'GitTree(sha="f492784d8ca837779650d1fb406a1a3587a764ad")')
\ No newline at end of file
