@@ -37,3 +37,6 @@ class Tag(Framework.TestCase):
         self.assertEqual(self.tag.name, "v0.3")
         self.assertEqual(self.tag.tarball_url, "https://github.com/jacquev6/PyGithub/tarball/v0.3")
         self.assertEqual(self.tag.zipball_url, "https://github.com/jacquev6/PyGithub/zipball/v0.3")
+
+        # test __repr__() based on this attributes
+        self.assertEqual(self.tag.__repr__(), 'Tag(name="v0.3", commit=Commit(sha="636e6112deb72277b3bffcc3303cd7e8a7431a5d"))')
